quickswitch for i3
==================

Overview
--------
This utility for i3, inspired by Pentadactyl's :buffers command, allows you to
quickly switch to and locate windows on all your workspaces, using an
interactive dmenu prompt.

Here's how it looks in action:

.. image:: http://i.imgur.com/QeQrM.png

Dependencies
------------
quickswitch requires dmenu (which you likely already have installed), and
i3-py, which you can install with ``pip install i3-py``.

quickswitch was tested in Python 2.7.3 and 3.2.3.

Installation
------------
Quickswitch has a PyPI entry, so you can install it with ``pip install
quickswitch-i3``. Alternatively, you can always manually run the setup file with
``python setup.py install``.

Additionally, if you are an Arch user, you can install it from the AUR. The
package is called ``quickswitch-i3``. The PKGBUILD is also included here.
